pub struct SeekableAsyncFile { /* private fields */ }Expand description
A File-like value that can perform async read_at and write_at for I/O at specific offsets without mutating any state (i.e. is thread safe). Metrics are collected, and syncs can be delayed for write batching opportunities as a performance optimisation.
Implementations
Sourceimpl SeekableAsyncFile
impl SeekableAsyncFile
pub async fn open( io: Arc<dyn IAsyncIO>, metrics: Arc<SeekableAsyncFileMetrics>, sync_delay: Duration, ) -> Self
pub async fn read_at(&self, offset: u64, len: u64) -> Vec<u8> ⓘ
pub async fn write_at<D: AsRef<[u8]> + Send + 'static>( &self, offset: u64, data: D, )
pub async fn write_at_with_delayed_sync<D: AsRef<[u8]> + Send + 'static>( &self, writes: impl IntoIterator<Item = WriteRequest<D>>, )
pub async fn start_delayed_data_sync_background_loop(&self)
pub async fn sync_data(&self)